/**
Copyright (c) 2012, DRAX <drax@drax.biz>
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of the FreeBSD Project.
*/

// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Window
{
	id: window

	function getStateName()
	{
		return "Game Browser"
	}

	function initialize()
	{
		return true;
	}

	function connectToGame(gameName)
	{
		//it is required for auto-skipping windowJoinedGame when going back from finished game
		windowMultiplayerCrosswordsClient.isFinished = false

		if (!networkClient.connectToGame(gameName))
			console.debug("Unable to start connections with game: " + gameName)
	}

	onShow:
	{
		windowMultiplayerCrosswordsClient.isFinished = false
		gamesListScroll.clear()
		networkClient.searchHostedGames()
	}

	onHidden: networkClient.stopSearchingHostedGames()

	Connections
	{
		target: networkClient

		onNewGameFound: gamesListScroll.addText(gameName)

		onConnectedToHost: setState(windowJoinedGame)

		onGameParameters: windowJoinedGame.setParameters(dictionary, maxPlayers, rows, columns, lettersCount,
														 guaranteeWord, expandableWords, doubleScoreEnabled,
														 doubleScore, penaltyForUnusedLetters, roundTime,
														 roundLimitEnabled, roundLimit,
														 scorelessRoundLimitEnabled, scorelessRoundLimit)

	}

	ListScroll {
		id: gamesListScroll
		anchors.bottom: refreshButton.top
		anchors.right: parent.right
		anchors.left: parent.left
		anchors.top: parent.top
		anchors.margins: 10

		doAnimations: window.doAnimations
		smooth: window.smooth

		onSelectedValueChanged: connectToGame(value)
	}

	Button {
		id: refreshButton
		anchors.bottom: parent.bottom
		anchors.bottomMargin: 10
		anchors.horizontalCenter: parent.horizontalCenter

		text: qsTr("Refresh")

		doAnimations: window.doAnimations
		smooth: window.smooth

		mouseArea.onReleased:
		{
			networkClient.clearGames()
			gamesListScroll.clear()
		}
	}


}
